/**
 * Created by user on 2018/5/6/006.
 */
import { ICreateRegExp, ITypeCreateRegExp } from '../../index';
import { IPatternTestRow } from '../../pattern';
export declare const KEY_PREFIX = "\\p{Script=";
export declare const KEY_PREFIX_NEGATION = "\\P{Script=";
export declare const KEY_SUFFIX = "}";
/**
 * @link http://2ality.com/2017/07/regexp-unicode-property-escapes.html
 * @link https://en.wikipedia.org/wiki/Unicode_character_property
 */
export declare const UNICODE_SCRIPTS: {
    Greek: boolean;
    Latin: boolean;
    Katakana: boolean;
    Hiragana: boolean;
    Han: boolean;
    Hangul: boolean;
};
export declare const UNICODE_SCRIPTS_ALL: {
    Greek: boolean;
    Latin: boolean;
    Katakana: boolean;
    Hiragana: boolean;
    Han: boolean;
    Hangul: boolean;
    Adlam: boolean;
    Adlm: boolean;
    Ahom: boolean;
    Anatolian_Hieroglyphs: boolean;
    Hluw: boolean;
    Arabic: boolean;
    Arab: boolean;
    Armenian: boolean;
    Armn: boolean;
    Avestan: boolean;
    Avst: boolean;
    Balinese: boolean;
    Bali: boolean;
    Bamum: boolean;
    Bamu: boolean;
    Bassa_Vah: boolean;
    Bass: boolean;
    Batak: boolean;
    Batk: boolean;
    Bengali: boolean;
    Beng: boolean;
    Bhaiksuki: boolean;
    Bhks: boolean;
    Bopomofo: boolean;
    Bopo: boolean;
    Brahmi: boolean;
    Brah: boolean;
    Braille: boolean;
    Brai: boolean;
    Buginese: boolean;
    Bugi: boolean;
    Buhid: boolean;
    Buhd: boolean;
    Canadian_Aboriginal: boolean;
    Cans: boolean;
    Carian: boolean;
    Cari: boolean;
    Caucasian_Albanian: boolean;
    Aghb: boolean;
    Chakma: boolean;
    Cakm: boolean;
    Cham: boolean;
    Cherokee: boolean;
    Cher: boolean;
    Common: boolean;
    Zyyy: boolean;
    Coptic: boolean;
    Copt: boolean;
    Qaac: boolean;
    Cuneiform: boolean;
    Xsux: boolean;
    Cypriot: boolean;
    Cprt: boolean;
    Cyrillic: boolean;
    Cyrl: boolean;
    Deseret: boolean;
    Dsrt: boolean;
    Devanagari: boolean;
    Deva: boolean;
    Duployan: boolean;
    Dupl: boolean;
    Egyptian_Hieroglyphs: boolean;
    Egyp: boolean;
    Elbasan: boolean;
    Elba: boolean;
    Ethiopic: boolean;
    Ethi: boolean;
    Georgian: boolean;
    Geor: boolean;
    Glagolitic: boolean;
    Glag: boolean;
    Gothic: boolean;
    Goth: boolean;
    Grantha: boolean;
    Gran: boolean;
    Grek: boolean;
    Gujarati: boolean;
    Gujr: boolean;
    Gurmukhi: boolean;
    Guru: boolean;
    Hani: boolean;
    Hang: boolean;
    Hanunoo: boolean;
    Hano: boolean;
    Hatran: boolean;
    Hatr: boolean;
    Hebrew: boolean;
    Hebr: boolean;
    Hira: boolean;
    Imperial_Aramaic: boolean;
    Armi: boolean;
    Inherited: boolean;
    Zinh: boolean;
    Qaai: boolean;
    Inscriptional_Pahlavi: boolean;
    Phli: boolean;
    Inscriptional_Parthian: boolean;
    Prti: boolean;
    Javanese: boolean;
    Java: boolean;
    Kaithi: boolean;
    Kthi: boolean;
    Kannada: boolean;
    Knda: boolean;
    Kana: boolean;
    Kayah_Li: boolean;
    Kali: boolean;
    Kharoshthi: boolean;
    Khar: boolean;
    Khmer: boolean;
    Khmr: boolean;
    Khojki: boolean;
    Khoj: boolean;
    Khudawadi: boolean;
    Sind: boolean;
    Lao: boolean;
    Laoo: boolean;
    Latn: boolean;
    Lepcha: boolean;
    Lepc: boolean;
    Limbu: boolean;
    Limb: boolean;
    Linear_A: boolean;
    Lina: boolean;
    Linear_B: boolean;
    Linb: boolean;
    Lisu: boolean;
    Lycian: boolean;
    Lyci: boolean;
    Lydian: boolean;
    Lydi: boolean;
    Mahajani: boolean;
    Mahj: boolean;
    Malayalam: boolean;
    Mlym: boolean;
    Mandaic: boolean;
    Mand: boolean;
    Manichaean: boolean;
    Mani: boolean;
    Marchen: boolean;
    Marc: boolean;
    Masaram_Gondi: boolean;
    Gonm: boolean;
    Meetei_Mayek: boolean;
    Mtei: boolean;
    Mende_Kikakui: boolean;
    Mend: boolean;
    Meroitic_Cursive: boolean;
    Merc: boolean;
    Meroitic_Hieroglyphs: boolean;
    Mero: boolean;
    Miao: boolean;
    Plrd: boolean;
    Modi: boolean;
    Mongolian: boolean;
    Mong: boolean;
    Mro: boolean;
    Mroo: boolean;
    Multani: boolean;
    Mult: boolean;
    Myanmar: boolean;
    Mymr: boolean;
    Nabataean: boolean;
    Nbat: boolean;
    New_Tai_Lue: boolean;
    Talu: boolean;
    Newa: boolean;
    Nko: boolean;
    Nkoo: boolean;
    Nushu: boolean;
    Nshu: boolean;
    Ogham: boolean;
    Ogam: boolean;
    Ol_Chiki: boolean;
    Olck: boolean;
    Old_Hungarian: boolean;
    Hung: boolean;
    Old_Italic: boolean;
    Ital: boolean;
    Old_North_Arabian: boolean;
    Narb: boolean;
    Old_Permic: boolean;
    Perm: boolean;
    Old_Persian: boolean;
    Xpeo: boolean;
    Old_South_Arabian: boolean;
    Sarb: boolean;
    Old_Turkic: boolean;
    Orkh: boolean;
    Oriya: boolean;
    Orya: boolean;
    Osage: boolean;
    Osge: boolean;
    Osmanya: boolean;
    Osma: boolean;
    Pahawh_Hmong: boolean;
    Hmng: boolean;
    Palmyrene: boolean;
    Palm: boolean;
    Pau_Cin_Hau: boolean;
    Pauc: boolean;
    Phags_Pa: boolean;
    Phag: boolean;
    Phoenician: boolean;
    Phnx: boolean;
    Psalter_Pahlavi: boolean;
    Phlp: boolean;
    Rejang: boolean;
    Rjng: boolean;
    Runic: boolean;
    Runr: boolean;
    Samaritan: boolean;
    Samr: boolean;
    Saurashtra: boolean;
    Saur: boolean;
    Sharada: boolean;
    Shrd: boolean;
    Shavian: boolean;
    Shaw: boolean;
    Siddham: boolean;
    Sidd: boolean;
    SignWriting: boolean;
    Sgnw: boolean;
    Sinhala: boolean;
    Sinh: boolean;
    Sora_Sompeng: boolean;
    Sora: boolean;
    Soyombo: boolean;
    Soyo: boolean;
    Sundanese: boolean;
    Sund: boolean;
    Syloti_Nagri: boolean;
    Sylo: boolean;
    Syriac: boolean;
    Syrc: boolean;
    Tagalog: boolean;
    Tglg: boolean;
    Tagbanwa: boolean;
    Tagb: boolean;
    Tai_Le: boolean;
    Tale: boolean;
    Tai_Tham: boolean;
    Lana: boolean;
    Tai_Viet: boolean;
    Tavt: boolean;
    Takri: boolean;
    Takr: boolean;
    Tamil: boolean;
    Taml: boolean;
    Tangut: boolean;
    Tang: boolean;
    Telugu: boolean;
    Telu: boolean;
    Thaana: boolean;
    Thaa: boolean;
    Thai: boolean;
    Tibetan: boolean;
    Tibt: boolean;
    Tifinagh: boolean;
    Tfng: boolean;
    Tirhuta: boolean;
    Tirh: boolean;
    Ugaritic: boolean;
    Ugar: boolean;
    Vai: boolean;
    Vaii: boolean;
    Warang_Citi: boolean;
    Wara: boolean;
    Yi: boolean;
    Yiii: boolean;
    Zanabazar_Square: boolean;
    Zanb: boolean;
    Dogra: boolean;
    Gunjala_Gondi: boolean;
    Hanifi_Rohingya: boolean;
    Makasar: boolean;
    Medefaidrin: boolean;
    Old_Sogdian: boolean;
    Sogdian: boolean;
};
export declare enum UNICODE_SCRIPTS_NAME_ALIAS {
    Arabic = "Arab",
    Bengali = "Beng",
    Coptic = "Copt",
    Cyrillic = "Cyrl",
    Ethiopic = "Ethi",
    Georgian = "Geor",
    Greek = "Grek",
    Han = "Hani",
    Katakana = "Kana",
    Hiragana = "Hira",
    Latin = "Latn",
    Tamil = "Taml",
    Tibetan = "Tibt"
}
export declare const PatternTest: {
    [k in keyof typeof UNICODE_SCRIPTS_ALL]?: IPatternTestRow[];
};
export declare const _testUnicodeScript: {
    (name: string, RegExpClass?: typeof RegExp, testPatterns?: {
        Greek?: IPatternTestRow[];
        Latin?: IPatternTestRow[];
        Katakana?: IPatternTestRow[];
        Hiragana?: IPatternTestRow[];
        Han?: IPatternTestRow[];
        Hangul?: IPatternTestRow[];
        Adlam?: IPatternTestRow[];
        Adlm?: IPatternTestRow[];
        Ahom?: IPatternTestRow[];
        Anatolian_Hieroglyphs?: IPatternTestRow[];
        Hluw?: IPatternTestRow[];
        Arabic?: IPatternTestRow[];
        Arab?: IPatternTestRow[];
        Armenian?: IPatternTestRow[];
        Armn?: IPatternTestRow[];
        Avestan?: IPatternTestRow[];
        Avst?: IPatternTestRow[];
        Balinese?: IPatternTestRow[];
        Bali?: IPatternTestRow[];
        Bamum?: IPatternTestRow[];
        Bamu?: IPatternTestRow[];
        Bassa_Vah?: IPatternTestRow[];
        Bass?: IPatternTestRow[];
        Batak?: IPatternTestRow[];
        Batk?: IPatternTestRow[];
        Bengali?: IPatternTestRow[];
        Beng?: IPatternTestRow[];
        Bhaiksuki?: IPatternTestRow[];
        Bhks?: IPatternTestRow[];
        Bopomofo?: IPatternTestRow[];
        Bopo?: IPatternTestRow[];
        Brahmi?: IPatternTestRow[];
        Brah?: IPatternTestRow[];
        Braille?: IPatternTestRow[];
        Brai?: IPatternTestRow[];
        Buginese?: IPatternTestRow[];
        Bugi?: IPatternTestRow[];
        Buhid?: IPatternTestRow[];
        Buhd?: IPatternTestRow[];
        Canadian_Aboriginal?: IPatternTestRow[];
        Cans?: IPatternTestRow[];
        Carian?: IPatternTestRow[];
        Cari?: IPatternTestRow[];
        Caucasian_Albanian?: IPatternTestRow[];
        Aghb?: IPatternTestRow[];
        Chakma?: IPatternTestRow[];
        Cakm?: IPatternTestRow[];
        Cham?: IPatternTestRow[];
        Cherokee?: IPatternTestRow[];
        Cher?: IPatternTestRow[];
        Common?: IPatternTestRow[];
        Zyyy?: IPatternTestRow[];
        Coptic?: IPatternTestRow[];
        Copt?: IPatternTestRow[];
        Qaac?: IPatternTestRow[];
        Cuneiform?: IPatternTestRow[];
        Xsux?: IPatternTestRow[];
        Cypriot?: IPatternTestRow[];
        Cprt?: IPatternTestRow[];
        Cyrillic?: IPatternTestRow[];
        Cyrl?: IPatternTestRow[];
        Deseret?: IPatternTestRow[];
        Dsrt?: IPatternTestRow[];
        Devanagari?: IPatternTestRow[];
        Deva?: IPatternTestRow[];
        Duployan?: IPatternTestRow[];
        Dupl?: IPatternTestRow[];
        Egyptian_Hieroglyphs?: IPatternTestRow[];
        Egyp?: IPatternTestRow[];
        Elbasan?: IPatternTestRow[];
        Elba?: IPatternTestRow[];
        Ethiopic?: IPatternTestRow[];
        Ethi?: IPatternTestRow[];
        Georgian?: IPatternTestRow[];
        Geor?: IPatternTestRow[];
        Glagolitic?: IPatternTestRow[];
        Glag?: IPatternTestRow[];
        Gothic?: IPatternTestRow[];
        Goth?: IPatternTestRow[];
        Grantha?: IPatternTestRow[];
        Gran?: IPatternTestRow[];
        Grek?: IPatternTestRow[];
        Gujarati?: IPatternTestRow[];
        Gujr?: IPatternTestRow[];
        Gurmukhi?: IPatternTestRow[];
        Guru?: IPatternTestRow[];
        Hani?: IPatternTestRow[];
        Hang?: IPatternTestRow[];
        Hanunoo?: IPatternTestRow[];
        Hano?: IPatternTestRow[];
        Hatran?: IPatternTestRow[];
        Hatr?: IPatternTestRow[];
        Hebrew?: IPatternTestRow[];
        Hebr?: IPatternTestRow[];
        Hira?: IPatternTestRow[];
        Imperial_Aramaic?: IPatternTestRow[];
        Armi?: IPatternTestRow[];
        Inherited?: IPatternTestRow[];
        Zinh?: IPatternTestRow[];
        Qaai?: IPatternTestRow[];
        Inscriptional_Pahlavi?: IPatternTestRow[];
        Phli?: IPatternTestRow[];
        Inscriptional_Parthian?: IPatternTestRow[];
        Prti?: IPatternTestRow[];
        Javanese?: IPatternTestRow[];
        Java?: IPatternTestRow[];
        Kaithi?: IPatternTestRow[];
        Kthi?: IPatternTestRow[];
        Kannada?: IPatternTestRow[];
        Knda?: IPatternTestRow[];
        Kana?: IPatternTestRow[];
        Kayah_Li?: IPatternTestRow[];
        Kali?: IPatternTestRow[];
        Kharoshthi?: IPatternTestRow[];
        Khar?: IPatternTestRow[];
        Khmer?: IPatternTestRow[];
        Khmr?: IPatternTestRow[];
        Khojki?: IPatternTestRow[];
        Khoj?: IPatternTestRow[];
        Khudawadi?: IPatternTestRow[];
        Sind?: IPatternTestRow[];
        Lao?: IPatternTestRow[];
        Laoo?: IPatternTestRow[];
        Latn?: IPatternTestRow[];
        Lepcha?: IPatternTestRow[];
        Lepc?: IPatternTestRow[];
        Limbu?: IPatternTestRow[];
        Limb?: IPatternTestRow[];
        Linear_A?: IPatternTestRow[];
        Lina?: IPatternTestRow[];
        Linear_B?: IPatternTestRow[];
        Linb?: IPatternTestRow[];
        Lisu?: IPatternTestRow[];
        Lycian?: IPatternTestRow[];
        Lyci?: IPatternTestRow[];
        Lydian?: IPatternTestRow[];
        Lydi?: IPatternTestRow[];
        Mahajani?: IPatternTestRow[];
        Mahj?: IPatternTestRow[];
        Malayalam?: IPatternTestRow[];
        Mlym?: IPatternTestRow[];
        Mandaic?: IPatternTestRow[];
        Mand?: IPatternTestRow[];
        Manichaean?: IPatternTestRow[];
        Mani?: IPatternTestRow[];
        Marchen?: IPatternTestRow[];
        Marc?: IPatternTestRow[];
        Masaram_Gondi?: IPatternTestRow[];
        Gonm?: IPatternTestRow[];
        Meetei_Mayek?: IPatternTestRow[];
        Mtei?: IPatternTestRow[];
        Mende_Kikakui?: IPatternTestRow[];
        Mend?: IPatternTestRow[];
        Meroitic_Cursive?: IPatternTestRow[];
        Merc?: IPatternTestRow[];
        Meroitic_Hieroglyphs?: IPatternTestRow[];
        Mero?: IPatternTestRow[];
        Miao?: IPatternTestRow[];
        Plrd?: IPatternTestRow[];
        Modi?: IPatternTestRow[];
        Mongolian?: IPatternTestRow[];
        Mong?: IPatternTestRow[];
        Mro?: IPatternTestRow[];
        Mroo?: IPatternTestRow[];
        Multani?: IPatternTestRow[];
        Mult?: IPatternTestRow[];
        Myanmar?: IPatternTestRow[];
        Mymr?: IPatternTestRow[];
        Nabataean?: IPatternTestRow[];
        Nbat?: IPatternTestRow[];
        New_Tai_Lue?: IPatternTestRow[];
        Talu?: IPatternTestRow[];
        Newa?: IPatternTestRow[];
        Nko?: IPatternTestRow[];
        Nkoo?: IPatternTestRow[];
        Nushu?: IPatternTestRow[];
        Nshu?: IPatternTestRow[];
        Ogham?: IPatternTestRow[];
        Ogam?: IPatternTestRow[];
        Ol_Chiki?: IPatternTestRow[];
        Olck?: IPatternTestRow[];
        Old_Hungarian?: IPatternTestRow[];
        Hung?: IPatternTestRow[];
        Old_Italic?: IPatternTestRow[];
        Ital?: IPatternTestRow[];
        Old_North_Arabian?: IPatternTestRow[];
        Narb?: IPatternTestRow[];
        Old_Permic?: IPatternTestRow[];
        Perm?: IPatternTestRow[];
        Old_Persian?: IPatternTestRow[];
        Xpeo?: IPatternTestRow[];
        Old_South_Arabian?: IPatternTestRow[];
        Sarb?: IPatternTestRow[];
        Old_Turkic?: IPatternTestRow[];
        Orkh?: IPatternTestRow[];
        Oriya?: IPatternTestRow[];
        Orya?: IPatternTestRow[];
        Osage?: IPatternTestRow[];
        Osge?: IPatternTestRow[];
        Osmanya?: IPatternTestRow[];
        Osma?: IPatternTestRow[];
        Pahawh_Hmong?: IPatternTestRow[];
        Hmng?: IPatternTestRow[];
        Palmyrene?: IPatternTestRow[];
        Palm?: IPatternTestRow[];
        Pau_Cin_Hau?: IPatternTestRow[];
        Pauc?: IPatternTestRow[];
        Phags_Pa?: IPatternTestRow[];
        Phag?: IPatternTestRow[];
        Phoenician?: IPatternTestRow[];
        Phnx?: IPatternTestRow[];
        Psalter_Pahlavi?: IPatternTestRow[];
        Phlp?: IPatternTestRow[];
        Rejang?: IPatternTestRow[];
        Rjng?: IPatternTestRow[];
        Runic?: IPatternTestRow[];
        Runr?: IPatternTestRow[];
        Samaritan?: IPatternTestRow[];
        Samr?: IPatternTestRow[];
        Saurashtra?: IPatternTestRow[];
        Saur?: IPatternTestRow[];
        Sharada?: IPatternTestRow[];
        Shrd?: IPatternTestRow[];
        Shavian?: IPatternTestRow[];
        Shaw?: IPatternTestRow[];
        Siddham?: IPatternTestRow[];
        Sidd?: IPatternTestRow[];
        SignWriting?: IPatternTestRow[];
        Sgnw?: IPatternTestRow[];
        Sinhala?: IPatternTestRow[];
        Sinh?: IPatternTestRow[];
        Sora_Sompeng?: IPatternTestRow[];
        Sora?: IPatternTestRow[];
        Soyombo?: IPatternTestRow[];
        Soyo?: IPatternTestRow[];
        Sundanese?: IPatternTestRow[];
        Sund?: IPatternTestRow[];
        Syloti_Nagri?: IPatternTestRow[];
        Sylo?: IPatternTestRow[];
        Syriac?: IPatternTestRow[];
        Syrc?: IPatternTestRow[];
        Tagalog?: IPatternTestRow[];
        Tglg?: IPatternTestRow[];
        Tagbanwa?: IPatternTestRow[];
        Tagb?: IPatternTestRow[];
        Tai_Le?: IPatternTestRow[];
        Tale?: IPatternTestRow[];
        Tai_Tham?: IPatternTestRow[];
        Lana?: IPatternTestRow[];
        Tai_Viet?: IPatternTestRow[];
        Tavt?: IPatternTestRow[];
        Takri?: IPatternTestRow[];
        Takr?: IPatternTestRow[];
        Tamil?: IPatternTestRow[];
        Taml?: IPatternTestRow[];
        Tangut?: IPatternTestRow[];
        Tang?: IPatternTestRow[];
        Telugu?: IPatternTestRow[];
        Telu?: IPatternTestRow[];
        Thaana?: IPatternTestRow[];
        Thaa?: IPatternTestRow[];
        Thai?: IPatternTestRow[];
        Tibetan?: IPatternTestRow[];
        Tibt?: IPatternTestRow[];
        Tifinagh?: IPatternTestRow[];
        Tfng?: IPatternTestRow[];
        Tirhuta?: IPatternTestRow[];
        Tirh?: IPatternTestRow[];
        Ugaritic?: IPatternTestRow[];
        Ugar?: IPatternTestRow[];
        Vai?: IPatternTestRow[];
        Vaii?: IPatternTestRow[];
        Warang_Citi?: IPatternTestRow[];
        Wara?: IPatternTestRow[];
        Yi?: IPatternTestRow[];
        Yiii?: IPatternTestRow[];
        Zanabazar_Square?: IPatternTestRow[];
        Zanb?: IPatternTestRow[];
        Dogra?: IPatternTestRow[];
        Gunjala_Gondi?: IPatternTestRow[];
        Hanifi_Rohingya?: IPatternTestRow[];
        Makasar?: IPatternTestRow[];
        Medefaidrin?: IPatternTestRow[];
        Old_Sogdian?: IPatternTestRow[];
        Sogdian?: IPatternTestRow[];
    }): boolean;
    (name: string, RegExpClass?: ICreateRegExp, testPatterns?: {
        Greek?: IPatternTestRow[];
        Latin?: IPatternTestRow[];
        Katakana?: IPatternTestRow[];
        Hiragana?: IPatternTestRow[];
        Han?: IPatternTestRow[];
        Hangul?: IPatternTestRow[];
        Adlam?: IPatternTestRow[];
        Adlm?: IPatternTestRow[];
        Ahom?: IPatternTestRow[];
        Anatolian_Hieroglyphs?: IPatternTestRow[];
        Hluw?: IPatternTestRow[];
        Arabic?: IPatternTestRow[];
        Arab?: IPatternTestRow[];
        Armenian?: IPatternTestRow[];
        Armn?: IPatternTestRow[];
        Avestan?: IPatternTestRow[];
        Avst?: IPatternTestRow[];
        Balinese?: IPatternTestRow[];
        Bali?: IPatternTestRow[];
        Bamum?: IPatternTestRow[];
        Bamu?: IPatternTestRow[];
        Bassa_Vah?: IPatternTestRow[];
        Bass?: IPatternTestRow[];
        Batak?: IPatternTestRow[];
        Batk?: IPatternTestRow[];
        Bengali?: IPatternTestRow[];
        Beng?: IPatternTestRow[];
        Bhaiksuki?: IPatternTestRow[];
        Bhks?: IPatternTestRow[];
        Bopomofo?: IPatternTestRow[];
        Bopo?: IPatternTestRow[];
        Brahmi?: IPatternTestRow[];
        Brah?: IPatternTestRow[];
        Braille?: IPatternTestRow[];
        Brai?: IPatternTestRow[];
        Buginese?: IPatternTestRow[];
        Bugi?: IPatternTestRow[];
        Buhid?: IPatternTestRow[];
        Buhd?: IPatternTestRow[];
        Canadian_Aboriginal?: IPatternTestRow[];
        Cans?: IPatternTestRow[];
        Carian?: IPatternTestRow[];
        Cari?: IPatternTestRow[];
        Caucasian_Albanian?: IPatternTestRow[];
        Aghb?: IPatternTestRow[];
        Chakma?: IPatternTestRow[];
        Cakm?: IPatternTestRow[];
        Cham?: IPatternTestRow[];
        Cherokee?: IPatternTestRow[];
        Cher?: IPatternTestRow[];
        Common?: IPatternTestRow[];
        Zyyy?: IPatternTestRow[];
        Coptic?: IPatternTestRow[];
        Copt?: IPatternTestRow[];
        Qaac?: IPatternTestRow[];
        Cuneiform?: IPatternTestRow[];
        Xsux?: IPatternTestRow[];
        Cypriot?: IPatternTestRow[];
        Cprt?: IPatternTestRow[];
        Cyrillic?: IPatternTestRow[];
        Cyrl?: IPatternTestRow[];
        Deseret?: IPatternTestRow[];
        Dsrt?: IPatternTestRow[];
        Devanagari?: IPatternTestRow[];
        Deva?: IPatternTestRow[];
        Duployan?: IPatternTestRow[];
        Dupl?: IPatternTestRow[];
        Egyptian_Hieroglyphs?: IPatternTestRow[];
        Egyp?: IPatternTestRow[];
        Elbasan?: IPatternTestRow[];
        Elba?: IPatternTestRow[];
        Ethiopic?: IPatternTestRow[];
        Ethi?: IPatternTestRow[];
        Georgian?: IPatternTestRow[];
        Geor?: IPatternTestRow[];
        Glagolitic?: IPatternTestRow[];
        Glag?: IPatternTestRow[];
        Gothic?: IPatternTestRow[];
        Goth?: IPatternTestRow[];
        Grantha?: IPatternTestRow[];
        Gran?: IPatternTestRow[];
        Grek?: IPatternTestRow[];
        Gujarati?: IPatternTestRow[];
        Gujr?: IPatternTestRow[];
        Gurmukhi?: IPatternTestRow[];
        Guru?: IPatternTestRow[];
        Hani?: IPatternTestRow[];
        Hang?: IPatternTestRow[];
        Hanunoo?: IPatternTestRow[];
        Hano?: IPatternTestRow[];
        Hatran?: IPatternTestRow[];
        Hatr?: IPatternTestRow[];
        Hebrew?: IPatternTestRow[];
        Hebr?: IPatternTestRow[];
        Hira?: IPatternTestRow[];
        Imperial_Aramaic?: IPatternTestRow[];
        Armi?: IPatternTestRow[];
        Inherited?: IPatternTestRow[];
        Zinh?: IPatternTestRow[];
        Qaai?: IPatternTestRow[];
        Inscriptional_Pahlavi?: IPatternTestRow[];
        Phli?: IPatternTestRow[];
        Inscriptional_Parthian?: IPatternTestRow[];
        Prti?: IPatternTestRow[];
        Javanese?: IPatternTestRow[];
        Java?: IPatternTestRow[];
        Kaithi?: IPatternTestRow[];
        Kthi?: IPatternTestRow[];
        Kannada?: IPatternTestRow[];
        Knda?: IPatternTestRow[];
        Kana?: IPatternTestRow[];
        Kayah_Li?: IPatternTestRow[];
        Kali?: IPatternTestRow[];
        Kharoshthi?: IPatternTestRow[];
        Khar?: IPatternTestRow[];
        Khmer?: IPatternTestRow[];
        Khmr?: IPatternTestRow[];
        Khojki?: IPatternTestRow[];
        Khoj?: IPatternTestRow[];
        Khudawadi?: IPatternTestRow[];
        Sind?: IPatternTestRow[];
        Lao?: IPatternTestRow[];
        Laoo?: IPatternTestRow[];
        Latn?: IPatternTestRow[];
        Lepcha?: IPatternTestRow[];
        Lepc?: IPatternTestRow[];
        Limbu?: IPatternTestRow[];
        Limb?: IPatternTestRow[];
        Linear_A?: IPatternTestRow[];
        Lina?: IPatternTestRow[];
        Linear_B?: IPatternTestRow[];
        Linb?: IPatternTestRow[];
        Lisu?: IPatternTestRow[];
        Lycian?: IPatternTestRow[];
        Lyci?: IPatternTestRow[];
        Lydian?: IPatternTestRow[];
        Lydi?: IPatternTestRow[];
        Mahajani?: IPatternTestRow[];
        Mahj?: IPatternTestRow[];
        Malayalam?: IPatternTestRow[];
        Mlym?: IPatternTestRow[];
        Mandaic?: IPatternTestRow[];
        Mand?: IPatternTestRow[];
        Manichaean?: IPatternTestRow[];
        Mani?: IPatternTestRow[];
        Marchen?: IPatternTestRow[];
        Marc?: IPatternTestRow[];
        Masaram_Gondi?: IPatternTestRow[];
        Gonm?: IPatternTestRow[];
        Meetei_Mayek?: IPatternTestRow[];
        Mtei?: IPatternTestRow[];
        Mende_Kikakui?: IPatternTestRow[];
        Mend?: IPatternTestRow[];
        Meroitic_Cursive?: IPatternTestRow[];
        Merc?: IPatternTestRow[];
        Meroitic_Hieroglyphs?: IPatternTestRow[];
        Mero?: IPatternTestRow[];
        Miao?: IPatternTestRow[];
        Plrd?: IPatternTestRow[];
        Modi?: IPatternTestRow[];
        Mongolian?: IPatternTestRow[];
        Mong?: IPatternTestRow[];
        Mro?: IPatternTestRow[];
        Mroo?: IPatternTestRow[];
        Multani?: IPatternTestRow[];
        Mult?: IPatternTestRow[];
        Myanmar?: IPatternTestRow[];
        Mymr?: IPatternTestRow[];
        Nabataean?: IPatternTestRow[];
        Nbat?: IPatternTestRow[];
        New_Tai_Lue?: IPatternTestRow[];
        Talu?: IPatternTestRow[];
        Newa?: IPatternTestRow[];
        Nko?: IPatternTestRow[];
        Nkoo?: IPatternTestRow[];
        Nushu?: IPatternTestRow[];
        Nshu?: IPatternTestRow[];
        Ogham?: IPatternTestRow[];
        Ogam?: IPatternTestRow[];
        Ol_Chiki?: IPatternTestRow[];
        Olck?: IPatternTestRow[];
        Old_Hungarian?: IPatternTestRow[];
        Hung?: IPatternTestRow[];
        Old_Italic?: IPatternTestRow[];
        Ital?: IPatternTestRow[];
        Old_North_Arabian?: IPatternTestRow[];
        Narb?: IPatternTestRow[];
        Old_Permic?: IPatternTestRow[];
        Perm?: IPatternTestRow[];
        Old_Persian?: IPatternTestRow[];
        Xpeo?: IPatternTestRow[];
        Old_South_Arabian?: IPatternTestRow[];
        Sarb?: IPatternTestRow[];
        Old_Turkic?: IPatternTestRow[];
        Orkh?: IPatternTestRow[];
        Oriya?: IPatternTestRow[];
        Orya?: IPatternTestRow[];
        Osage?: IPatternTestRow[];
        Osge?: IPatternTestRow[];
        Osmanya?: IPatternTestRow[];
        Osma?: IPatternTestRow[];
        Pahawh_Hmong?: IPatternTestRow[];
        Hmng?: IPatternTestRow[];
        Palmyrene?: IPatternTestRow[];
        Palm?: IPatternTestRow[];
        Pau_Cin_Hau?: IPatternTestRow[];
        Pauc?: IPatternTestRow[];
        Phags_Pa?: IPatternTestRow[];
        Phag?: IPatternTestRow[];
        Phoenician?: IPatternTestRow[];
        Phnx?: IPatternTestRow[];
        Psalter_Pahlavi?: IPatternTestRow[];
        Phlp?: IPatternTestRow[];
        Rejang?: IPatternTestRow[];
        Rjng?: IPatternTestRow[];
        Runic?: IPatternTestRow[];
        Runr?: IPatternTestRow[];
        Samaritan?: IPatternTestRow[];
        Samr?: IPatternTestRow[];
        Saurashtra?: IPatternTestRow[];
        Saur?: IPatternTestRow[];
        Sharada?: IPatternTestRow[];
        Shrd?: IPatternTestRow[];
        Shavian?: IPatternTestRow[];
        Shaw?: IPatternTestRow[];
        Siddham?: IPatternTestRow[];
        Sidd?: IPatternTestRow[];
        SignWriting?: IPatternTestRow[];
        Sgnw?: IPatternTestRow[];
        Sinhala?: IPatternTestRow[];
        Sinh?: IPatternTestRow[];
        Sora_Sompeng?: IPatternTestRow[];
        Sora?: IPatternTestRow[];
        Soyombo?: IPatternTestRow[];
        Soyo?: IPatternTestRow[];
        Sundanese?: IPatternTestRow[];
        Sund?: IPatternTestRow[];
        Syloti_Nagri?: IPatternTestRow[];
        Sylo?: IPatternTestRow[];
        Syriac?: IPatternTestRow[];
        Syrc?: IPatternTestRow[];
        Tagalog?: IPatternTestRow[];
        Tglg?: IPatternTestRow[];
        Tagbanwa?: IPatternTestRow[];
        Tagb?: IPatternTestRow[];
        Tai_Le?: IPatternTestRow[];
        Tale?: IPatternTestRow[];
        Tai_Tham?: IPatternTestRow[];
        Lana?: IPatternTestRow[];
        Tai_Viet?: IPatternTestRow[];
        Tavt?: IPatternTestRow[];
        Takri?: IPatternTestRow[];
        Takr?: IPatternTestRow[];
        Tamil?: IPatternTestRow[];
        Taml?: IPatternTestRow[];
        Tangut?: IPatternTestRow[];
        Tang?: IPatternTestRow[];
        Telugu?: IPatternTestRow[];
        Telu?: IPatternTestRow[];
        Thaana?: IPatternTestRow[];
        Thaa?: IPatternTestRow[];
        Thai?: IPatternTestRow[];
        Tibetan?: IPatternTestRow[];
        Tibt?: IPatternTestRow[];
        Tifinagh?: IPatternTestRow[];
        Tfng?: IPatternTestRow[];
        Tirhuta?: IPatternTestRow[];
        Tirh?: IPatternTestRow[];
        Ugaritic?: IPatternTestRow[];
        Ugar?: IPatternTestRow[];
        Vai?: IPatternTestRow[];
        Vaii?: IPatternTestRow[];
        Warang_Citi?: IPatternTestRow[];
        Wara?: IPatternTestRow[];
        Yi?: IPatternTestRow[];
        Yiii?: IPatternTestRow[];
        Zanabazar_Square?: IPatternTestRow[];
        Zanb?: IPatternTestRow[];
        Dogra?: IPatternTestRow[];
        Gunjala_Gondi?: IPatternTestRow[];
        Hanifi_Rohingya?: IPatternTestRow[];
        Makasar?: IPatternTestRow[];
        Medefaidrin?: IPatternTestRow[];
        Old_Sogdian?: IPatternTestRow[];
        Sogdian?: IPatternTestRow[];
    }): boolean;
    <T>(name: string, RegExpClass?: ITypeCreateRegExp<T>, testPatterns?: {
        Greek?: IPatternTestRow[];
        Latin?: IPatternTestRow[];
        Katakana?: IPatternTestRow[];
        Hiragana?: IPatternTestRow[];
        Han?: IPatternTestRow[];
        Hangul?: IPatternTestRow[];
        Adlam?: IPatternTestRow[];
        Adlm?: IPatternTestRow[];
        Ahom?: IPatternTestRow[];
        Anatolian_Hieroglyphs?: IPatternTestRow[];
        Hluw?: IPatternTestRow[];
        Arabic?: IPatternTestRow[];
        Arab?: IPatternTestRow[];
        Armenian?: IPatternTestRow[];
        Armn?: IPatternTestRow[];
        Avestan?: IPatternTestRow[];
        Avst?: IPatternTestRow[];
        Balinese?: IPatternTestRow[];
        Bali?: IPatternTestRow[];
        Bamum?: IPatternTestRow[];
        Bamu?: IPatternTestRow[];
        Bassa_Vah?: IPatternTestRow[];
        Bass?: IPatternTestRow[];
        Batak?: IPatternTestRow[];
        Batk?: IPatternTestRow[];
        Bengali?: IPatternTestRow[];
        Beng?: IPatternTestRow[];
        Bhaiksuki?: IPatternTestRow[];
        Bhks?: IPatternTestRow[];
        Bopomofo?: IPatternTestRow[];
        Bopo?: IPatternTestRow[];
        Brahmi?: IPatternTestRow[];
        Brah?: IPatternTestRow[];
        Braille?: IPatternTestRow[];
        Brai?: IPatternTestRow[];
        Buginese?: IPatternTestRow[];
        Bugi?: IPatternTestRow[];
        Buhid?: IPatternTestRow[];
        Buhd?: IPatternTestRow[];
        Canadian_Aboriginal?: IPatternTestRow[];
        Cans?: IPatternTestRow[];
        Carian?: IPatternTestRow[];
        Cari?: IPatternTestRow[];
        Caucasian_Albanian?: IPatternTestRow[];
        Aghb?: IPatternTestRow[];
        Chakma?: IPatternTestRow[];
        Cakm?: IPatternTestRow[];
        Cham?: IPatternTestRow[];
        Cherokee?: IPatternTestRow[];
        Cher?: IPatternTestRow[];
        Common?: IPatternTestRow[];
        Zyyy?: IPatternTestRow[];
        Coptic?: IPatternTestRow[];
        Copt?: IPatternTestRow[];
        Qaac?: IPatternTestRow[];
        Cuneiform?: IPatternTestRow[];
        Xsux?: IPatternTestRow[];
        Cypriot?: IPatternTestRow[];
        Cprt?: IPatternTestRow[];
        Cyrillic?: IPatternTestRow[];
        Cyrl?: IPatternTestRow[];
        Deseret?: IPatternTestRow[];
        Dsrt?: IPatternTestRow[];
        Devanagari?: IPatternTestRow[];
        Deva?: IPatternTestRow[];
        Duployan?: IPatternTestRow[];
        Dupl?: IPatternTestRow[];
        Egyptian_Hieroglyphs?: IPatternTestRow[];
        Egyp?: IPatternTestRow[];
        Elbasan?: IPatternTestRow[];
        Elba?: IPatternTestRow[];
        Ethiopic?: IPatternTestRow[];
        Ethi?: IPatternTestRow[];
        Georgian?: IPatternTestRow[];
        Geor?: IPatternTestRow[];
        Glagolitic?: IPatternTestRow[];
        Glag?: IPatternTestRow[];
        Gothic?: IPatternTestRow[];
        Goth?: IPatternTestRow[];
        Grantha?: IPatternTestRow[];
        Gran?: IPatternTestRow[];
        Grek?: IPatternTestRow[];
        Gujarati?: IPatternTestRow[];
        Gujr?: IPatternTestRow[];
        Gurmukhi?: IPatternTestRow[];
        Guru?: IPatternTestRow[];
        Hani?: IPatternTestRow[];
        Hang?: IPatternTestRow[];
        Hanunoo?: IPatternTestRow[];
        Hano?: IPatternTestRow[];
        Hatran?: IPatternTestRow[];
        Hatr?: IPatternTestRow[];
        Hebrew?: IPatternTestRow[];
        Hebr?: IPatternTestRow[];
        Hira?: IPatternTestRow[];
        Imperial_Aramaic?: IPatternTestRow[];
        Armi?: IPatternTestRow[];
        Inherited?: IPatternTestRow[];
        Zinh?: IPatternTestRow[];
        Qaai?: IPatternTestRow[];
        Inscriptional_Pahlavi?: IPatternTestRow[];
        Phli?: IPatternTestRow[];
        Inscriptional_Parthian?: IPatternTestRow[];
        Prti?: IPatternTestRow[];
        Javanese?: IPatternTestRow[];
        Java?: IPatternTestRow[];
        Kaithi?: IPatternTestRow[];
        Kthi?: IPatternTestRow[];
        Kannada?: IPatternTestRow[];
        Knda?: IPatternTestRow[];
        Kana?: IPatternTestRow[];
        Kayah_Li?: IPatternTestRow[];
        Kali?: IPatternTestRow[];
        Kharoshthi?: IPatternTestRow[];
        Khar?: IPatternTestRow[];
        Khmer?: IPatternTestRow[];
        Khmr?: IPatternTestRow[];
        Khojki?: IPatternTestRow[];
        Khoj?: IPatternTestRow[];
        Khudawadi?: IPatternTestRow[];
        Sind?: IPatternTestRow[];
        Lao?: IPatternTestRow[];
        Laoo?: IPatternTestRow[];
        Latn?: IPatternTestRow[];
        Lepcha?: IPatternTestRow[];
        Lepc?: IPatternTestRow[];
        Limbu?: IPatternTestRow[];
        Limb?: IPatternTestRow[];
        Linear_A?: IPatternTestRow[];
        Lina?: IPatternTestRow[];
        Linear_B?: IPatternTestRow[];
        Linb?: IPatternTestRow[];
        Lisu?: IPatternTestRow[];
        Lycian?: IPatternTestRow[];
        Lyci?: IPatternTestRow[];
        Lydian?: IPatternTestRow[];
        Lydi?: IPatternTestRow[];
        Mahajani?: IPatternTestRow[];
        Mahj?: IPatternTestRow[];
        Malayalam?: IPatternTestRow[];
        Mlym?: IPatternTestRow[];
        Mandaic?: IPatternTestRow[];
        Mand?: IPatternTestRow[];
        Manichaean?: IPatternTestRow[];
        Mani?: IPatternTestRow[];
        Marchen?: IPatternTestRow[];
        Marc?: IPatternTestRow[];
        Masaram_Gondi?: IPatternTestRow[];
        Gonm?: IPatternTestRow[];
        Meetei_Mayek?: IPatternTestRow[];
        Mtei?: IPatternTestRow[];
        Mende_Kikakui?: IPatternTestRow[];
        Mend?: IPatternTestRow[];
        Meroitic_Cursive?: IPatternTestRow[];
        Merc?: IPatternTestRow[];
        Meroitic_Hieroglyphs?: IPatternTestRow[];
        Mero?: IPatternTestRow[];
        Miao?: IPatternTestRow[];
        Plrd?: IPatternTestRow[];
        Modi?: IPatternTestRow[];
        Mongolian?: IPatternTestRow[];
        Mong?: IPatternTestRow[];
        Mro?: IPatternTestRow[];
        Mroo?: IPatternTestRow[];
        Multani?: IPatternTestRow[];
        Mult?: IPatternTestRow[];
        Myanmar?: IPatternTestRow[];
        Mymr?: IPatternTestRow[];
        Nabataean?: IPatternTestRow[];
        Nbat?: IPatternTestRow[];
        New_Tai_Lue?: IPatternTestRow[];
        Talu?: IPatternTestRow[];
        Newa?: IPatternTestRow[];
        Nko?: IPatternTestRow[];
        Nkoo?: IPatternTestRow[];
        Nushu?: IPatternTestRow[];
        Nshu?: IPatternTestRow[];
        Ogham?: IPatternTestRow[];
        Ogam?: IPatternTestRow[];
        Ol_Chiki?: IPatternTestRow[];
        Olck?: IPatternTestRow[];
        Old_Hungarian?: IPatternTestRow[];
        Hung?: IPatternTestRow[];
        Old_Italic?: IPatternTestRow[];
        Ital?: IPatternTestRow[];
        Old_North_Arabian?: IPatternTestRow[];
        Narb?: IPatternTestRow[];
        Old_Permic?: IPatternTestRow[];
        Perm?: IPatternTestRow[];
        Old_Persian?: IPatternTestRow[];
        Xpeo?: IPatternTestRow[];
        Old_South_Arabian?: IPatternTestRow[];
        Sarb?: IPatternTestRow[];
        Old_Turkic?: IPatternTestRow[];
        Orkh?: IPatternTestRow[];
        Oriya?: IPatternTestRow[];
        Orya?: IPatternTestRow[];
        Osage?: IPatternTestRow[];
        Osge?: IPatternTestRow[];
        Osmanya?: IPatternTestRow[];
        Osma?: IPatternTestRow[];
        Pahawh_Hmong?: IPatternTestRow[];
        Hmng?: IPatternTestRow[];
        Palmyrene?: IPatternTestRow[];
        Palm?: IPatternTestRow[];
        Pau_Cin_Hau?: IPatternTestRow[];
        Pauc?: IPatternTestRow[];
        Phags_Pa?: IPatternTestRow[];
        Phag?: IPatternTestRow[];
        Phoenician?: IPatternTestRow[];
        Phnx?: IPatternTestRow[];
        Psalter_Pahlavi?: IPatternTestRow[];
        Phlp?: IPatternTestRow[];
        Rejang?: IPatternTestRow[];
        Rjng?: IPatternTestRow[];
        Runic?: IPatternTestRow[];
        Runr?: IPatternTestRow[];
        Samaritan?: IPatternTestRow[];
        Samr?: IPatternTestRow[];
        Saurashtra?: IPatternTestRow[];
        Saur?: IPatternTestRow[];
        Sharada?: IPatternTestRow[];
        Shrd?: IPatternTestRow[];
        Shavian?: IPatternTestRow[];
        Shaw?: IPatternTestRow[];
        Siddham?: IPatternTestRow[];
        Sidd?: IPatternTestRow[];
        SignWriting?: IPatternTestRow[];
        Sgnw?: IPatternTestRow[];
        Sinhala?: IPatternTestRow[];
        Sinh?: IPatternTestRow[];
        Sora_Sompeng?: IPatternTestRow[];
        Sora?: IPatternTestRow[];
        Soyombo?: IPatternTestRow[];
        Soyo?: IPatternTestRow[];
        Sundanese?: IPatternTestRow[];
        Sund?: IPatternTestRow[];
        Syloti_Nagri?: IPatternTestRow[];
        Sylo?: IPatternTestRow[];
        Syriac?: IPatternTestRow[];
        Syrc?: IPatternTestRow[];
        Tagalog?: IPatternTestRow[];
        Tglg?: IPatternTestRow[];
        Tagbanwa?: IPatternTestRow[];
        Tagb?: IPatternTestRow[];
        Tai_Le?: IPatternTestRow[];
        Tale?: IPatternTestRow[];
        Tai_Tham?: IPatternTestRow[];
        Lana?: IPatternTestRow[];
        Tai_Viet?: IPatternTestRow[];
        Tavt?: IPatternTestRow[];
        Takri?: IPatternTestRow[];
        Takr?: IPatternTestRow[];
        Tamil?: IPatternTestRow[];
        Taml?: IPatternTestRow[];
        Tangut?: IPatternTestRow[];
        Tang?: IPatternTestRow[];
        Telugu?: IPatternTestRow[];
        Telu?: IPatternTestRow[];
        Thaana?: IPatternTestRow[];
        Thaa?: IPatternTestRow[];
        Thai?: IPatternTestRow[];
        Tibetan?: IPatternTestRow[];
        Tibt?: IPatternTestRow[];
        Tifinagh?: IPatternTestRow[];
        Tfng?: IPatternTestRow[];
        Tirhuta?: IPatternTestRow[];
        Tirh?: IPatternTestRow[];
        Ugaritic?: IPatternTestRow[];
        Ugar?: IPatternTestRow[];
        Vai?: IPatternTestRow[];
        Vaii?: IPatternTestRow[];
        Warang_Citi?: IPatternTestRow[];
        Wara?: IPatternTestRow[];
        Yi?: IPatternTestRow[];
        Yiii?: IPatternTestRow[];
        Zanabazar_Square?: IPatternTestRow[];
        Zanb?: IPatternTestRow[];
        Dogra?: IPatternTestRow[];
        Gunjala_Gondi?: IPatternTestRow[];
        Hanifi_Rohingya?: IPatternTestRow[];
        Makasar?: IPatternTestRow[];
        Medefaidrin?: IPatternTestRow[];
        Old_Sogdian?: IPatternTestRow[];
        Sogdian?: IPatternTestRow[];
    }): boolean;
};
export declare function testUnicodeScript<T>(name: string, RegExpClass?: ITypeCreateRegExp<T>, testPatterns?: typeof PatternTest): boolean;
export declare function testUnicodeScriptAll<T>(RegExpClass?: ITypeCreateRegExp<T>, testPatterns?: {
    Greek?: IPatternTestRow[];
    Latin?: IPatternTestRow[];
    Katakana?: IPatternTestRow[];
    Hiragana?: IPatternTestRow[];
    Han?: IPatternTestRow[];
    Hangul?: IPatternTestRow[];
    Adlam?: IPatternTestRow[];
    Adlm?: IPatternTestRow[];
    Ahom?: IPatternTestRow[];
    Anatolian_Hieroglyphs?: IPatternTestRow[];
    Hluw?: IPatternTestRow[];
    Arabic?: IPatternTestRow[];
    Arab?: IPatternTestRow[];
    Armenian?: IPatternTestRow[];
    Armn?: IPatternTestRow[];
    Avestan?: IPatternTestRow[];
    Avst?: IPatternTestRow[];
    Balinese?: IPatternTestRow[];
    Bali?: IPatternTestRow[];
    Bamum?: IPatternTestRow[];
    Bamu?: IPatternTestRow[];
    Bassa_Vah?: IPatternTestRow[];
    Bass?: IPatternTestRow[];
    Batak?: IPatternTestRow[];
    Batk?: IPatternTestRow[];
    Bengali?: IPatternTestRow[];
    Beng?: IPatternTestRow[];
    Bhaiksuki?: IPatternTestRow[];
    Bhks?: IPatternTestRow[];
    Bopomofo?: IPatternTestRow[];
    Bopo?: IPatternTestRow[];
    Brahmi?: IPatternTestRow[];
    Brah?: IPatternTestRow[];
    Braille?: IPatternTestRow[];
    Brai?: IPatternTestRow[];
    Buginese?: IPatternTestRow[];
    Bugi?: IPatternTestRow[];
    Buhid?: IPatternTestRow[];
    Buhd?: IPatternTestRow[];
    Canadian_Aboriginal?: IPatternTestRow[];
    Cans?: IPatternTestRow[];
    Carian?: IPatternTestRow[];
    Cari?: IPatternTestRow[];
    Caucasian_Albanian?: IPatternTestRow[];
    Aghb?: IPatternTestRow[];
    Chakma?: IPatternTestRow[];
    Cakm?: IPatternTestRow[];
    Cham?: IPatternTestRow[];
    Cherokee?: IPatternTestRow[];
    Cher?: IPatternTestRow[];
    Common?: IPatternTestRow[];
    Zyyy?: IPatternTestRow[];
    Coptic?: IPatternTestRow[];
    Copt?: IPatternTestRow[];
    Qaac?: IPatternTestRow[];
    Cuneiform?: IPatternTestRow[];
    Xsux?: IPatternTestRow[];
    Cypriot?: IPatternTestRow[];
    Cprt?: IPatternTestRow[];
    Cyrillic?: IPatternTestRow[];
    Cyrl?: IPatternTestRow[];
    Deseret?: IPatternTestRow[];
    Dsrt?: IPatternTestRow[];
    Devanagari?: IPatternTestRow[];
    Deva?: IPatternTestRow[];
    Duployan?: IPatternTestRow[];
    Dupl?: IPatternTestRow[];
    Egyptian_Hieroglyphs?: IPatternTestRow[];
    Egyp?: IPatternTestRow[];
    Elbasan?: IPatternTestRow[];
    Elba?: IPatternTestRow[];
    Ethiopic?: IPatternTestRow[];
    Ethi?: IPatternTestRow[];
    Georgian?: IPatternTestRow[];
    Geor?: IPatternTestRow[];
    Glagolitic?: IPatternTestRow[];
    Glag?: IPatternTestRow[];
    Gothic?: IPatternTestRow[];
    Goth?: IPatternTestRow[];
    Grantha?: IPatternTestRow[];
    Gran?: IPatternTestRow[];
    Grek?: IPatternTestRow[];
    Gujarati?: IPatternTestRow[];
    Gujr?: IPatternTestRow[];
    Gurmukhi?: IPatternTestRow[];
    Guru?: IPatternTestRow[];
    Hani?: IPatternTestRow[];
    Hang?: IPatternTestRow[];
    Hanunoo?: IPatternTestRow[];
    Hano?: IPatternTestRow[];
    Hatran?: IPatternTestRow[];
    Hatr?: IPatternTestRow[];
    Hebrew?: IPatternTestRow[];
    Hebr?: IPatternTestRow[];
    Hira?: IPatternTestRow[];
    Imperial_Aramaic?: IPatternTestRow[];
    Armi?: IPatternTestRow[];
    Inherited?: IPatternTestRow[];
    Zinh?: IPatternTestRow[];
    Qaai?: IPatternTestRow[];
    Inscriptional_Pahlavi?: IPatternTestRow[];
    Phli?: IPatternTestRow[];
    Inscriptional_Parthian?: IPatternTestRow[];
    Prti?: IPatternTestRow[];
    Javanese?: IPatternTestRow[];
    Java?: IPatternTestRow[];
    Kaithi?: IPatternTestRow[];
    Kthi?: IPatternTestRow[];
    Kannada?: IPatternTestRow[];
    Knda?: IPatternTestRow[];
    Kana?: IPatternTestRow[];
    Kayah_Li?: IPatternTestRow[];
    Kali?: IPatternTestRow[];
    Kharoshthi?: IPatternTestRow[];
    Khar?: IPatternTestRow[];
    Khmer?: IPatternTestRow[];
    Khmr?: IPatternTestRow[];
    Khojki?: IPatternTestRow[];
    Khoj?: IPatternTestRow[];
    Khudawadi?: IPatternTestRow[];
    Sind?: IPatternTestRow[];
    Lao?: IPatternTestRow[];
    Laoo?: IPatternTestRow[];
    Latn?: IPatternTestRow[];
    Lepcha?: IPatternTestRow[];
    Lepc?: IPatternTestRow[];
    Limbu?: IPatternTestRow[];
    Limb?: IPatternTestRow[];
    Linear_A?: IPatternTestRow[];
    Lina?: IPatternTestRow[];
    Linear_B?: IPatternTestRow[];
    Linb?: IPatternTestRow[];
    Lisu?: IPatternTestRow[];
    Lycian?: IPatternTestRow[];
    Lyci?: IPatternTestRow[];
    Lydian?: IPatternTestRow[];
    Lydi?: IPatternTestRow[];
    Mahajani?: IPatternTestRow[];
    Mahj?: IPatternTestRow[];
    Malayalam?: IPatternTestRow[];
    Mlym?: IPatternTestRow[];
    Mandaic?: IPatternTestRow[];
    Mand?: IPatternTestRow[];
    Manichaean?: IPatternTestRow[];
    Mani?: IPatternTestRow[];
    Marchen?: IPatternTestRow[];
    Marc?: IPatternTestRow[];
    Masaram_Gondi?: IPatternTestRow[];
    Gonm?: IPatternTestRow[];
    Meetei_Mayek?: IPatternTestRow[];
    Mtei?: IPatternTestRow[];
    Mende_Kikakui?: IPatternTestRow[];
    Mend?: IPatternTestRow[];
    Meroitic_Cursive?: IPatternTestRow[];
    Merc?: IPatternTestRow[];
    Meroitic_Hieroglyphs?: IPatternTestRow[];
    Mero?: IPatternTestRow[];
    Miao?: IPatternTestRow[];
    Plrd?: IPatternTestRow[];
    Modi?: IPatternTestRow[];
    Mongolian?: IPatternTestRow[];
    Mong?: IPatternTestRow[];
    Mro?: IPatternTestRow[];
    Mroo?: IPatternTestRow[];
    Multani?: IPatternTestRow[];
    Mult?: IPatternTestRow[];
    Myanmar?: IPatternTestRow[];
    Mymr?: IPatternTestRow[];
    Nabataean?: IPatternTestRow[];
    Nbat?: IPatternTestRow[];
    New_Tai_Lue?: IPatternTestRow[];
    Talu?: IPatternTestRow[];
    Newa?: IPatternTestRow[];
    Nko?: IPatternTestRow[];
    Nkoo?: IPatternTestRow[];
    Nushu?: IPatternTestRow[];
    Nshu?: IPatternTestRow[];
    Ogham?: IPatternTestRow[];
    Ogam?: IPatternTestRow[];
    Ol_Chiki?: IPatternTestRow[];
    Olck?: IPatternTestRow[];
    Old_Hungarian?: IPatternTestRow[];
    Hung?: IPatternTestRow[];
    Old_Italic?: IPatternTestRow[];
    Ital?: IPatternTestRow[];
    Old_North_Arabian?: IPatternTestRow[];
    Narb?: IPatternTestRow[];
    Old_Permic?: IPatternTestRow[];
    Perm?: IPatternTestRow[];
    Old_Persian?: IPatternTestRow[];
    Xpeo?: IPatternTestRow[];
    Old_South_Arabian?: IPatternTestRow[];
    Sarb?: IPatternTestRow[];
    Old_Turkic?: IPatternTestRow[];
    Orkh?: IPatternTestRow[];
    Oriya?: IPatternTestRow[];
    Orya?: IPatternTestRow[];
    Osage?: IPatternTestRow[];
    Osge?: IPatternTestRow[];
    Osmanya?: IPatternTestRow[];
    Osma?: IPatternTestRow[];
    Pahawh_Hmong?: IPatternTestRow[];
    Hmng?: IPatternTestRow[];
    Palmyrene?: IPatternTestRow[];
    Palm?: IPatternTestRow[];
    Pau_Cin_Hau?: IPatternTestRow[];
    Pauc?: IPatternTestRow[];
    Phags_Pa?: IPatternTestRow[];
    Phag?: IPatternTestRow[];
    Phoenician?: IPatternTestRow[];
    Phnx?: IPatternTestRow[];
    Psalter_Pahlavi?: IPatternTestRow[];
    Phlp?: IPatternTestRow[];
    Rejang?: IPatternTestRow[];
    Rjng?: IPatternTestRow[];
    Runic?: IPatternTestRow[];
    Runr?: IPatternTestRow[];
    Samaritan?: IPatternTestRow[];
    Samr?: IPatternTestRow[];
    Saurashtra?: IPatternTestRow[];
    Saur?: IPatternTestRow[];
    Sharada?: IPatternTestRow[];
    Shrd?: IPatternTestRow[];
    Shavian?: IPatternTestRow[];
    Shaw?: IPatternTestRow[];
    Siddham?: IPatternTestRow[];
    Sidd?: IPatternTestRow[];
    SignWriting?: IPatternTestRow[];
    Sgnw?: IPatternTestRow[];
    Sinhala?: IPatternTestRow[];
    Sinh?: IPatternTestRow[];
    Sora_Sompeng?: IPatternTestRow[];
    Sora?: IPatternTestRow[];
    Soyombo?: IPatternTestRow[];
    Soyo?: IPatternTestRow[];
    Sundanese?: IPatternTestRow[];
    Sund?: IPatternTestRow[];
    Syloti_Nagri?: IPatternTestRow[];
    Sylo?: IPatternTestRow[];
    Syriac?: IPatternTestRow[];
    Syrc?: IPatternTestRow[];
    Tagalog?: IPatternTestRow[];
    Tglg?: IPatternTestRow[];
    Tagbanwa?: IPatternTestRow[];
    Tagb?: IPatternTestRow[];
    Tai_Le?: IPatternTestRow[];
    Tale?: IPatternTestRow[];
    Tai_Tham?: IPatternTestRow[];
    Lana?: IPatternTestRow[];
    Tai_Viet?: IPatternTestRow[];
    Tavt?: IPatternTestRow[];
    Takri?: IPatternTestRow[];
    Takr?: IPatternTestRow[];
    Tamil?: IPatternTestRow[];
    Taml?: IPatternTestRow[];
    Tangut?: IPatternTestRow[];
    Tang?: IPatternTestRow[];
    Telugu?: IPatternTestRow[];
    Telu?: IPatternTestRow[];
    Thaana?: IPatternTestRow[];
    Thaa?: IPatternTestRow[];
    Thai?: IPatternTestRow[];
    Tibetan?: IPatternTestRow[];
    Tibt?: IPatternTestRow[];
    Tifinagh?: IPatternTestRow[];
    Tfng?: IPatternTestRow[];
    Tirhuta?: IPatternTestRow[];
    Tirh?: IPatternTestRow[];
    Ugaritic?: IPatternTestRow[];
    Ugar?: IPatternTestRow[];
    Vai?: IPatternTestRow[];
    Vaii?: IPatternTestRow[];
    Warang_Citi?: IPatternTestRow[];
    Wara?: IPatternTestRow[];
    Yi?: IPatternTestRow[];
    Yiii?: IPatternTestRow[];
    Zanabazar_Square?: IPatternTestRow[];
    Zanb?: IPatternTestRow[];
    Dogra?: IPatternTestRow[];
    Gunjala_Gondi?: IPatternTestRow[];
    Hanifi_Rohingya?: IPatternTestRow[];
    Makasar?: IPatternTestRow[];
    Medefaidrin?: IPatternTestRow[];
    Old_Sogdian?: IPatternTestRow[];
    Sogdian?: IPatternTestRow[];
}): {
    Greek: boolean;
    Latin: boolean;
    Katakana: boolean;
    Hiragana: boolean;
    Han: boolean;
    Hangul: boolean;
    Adlam: boolean;
    Adlm: boolean;
    Ahom: boolean;
    Anatolian_Hieroglyphs: boolean;
    Hluw: boolean;
    Arabic: boolean;
    Arab: boolean;
    Armenian: boolean;
    Armn: boolean;
    Avestan: boolean;
    Avst: boolean;
    Balinese: boolean;
    Bali: boolean;
    Bamum: boolean;
    Bamu: boolean;
    Bassa_Vah: boolean;
    Bass: boolean;
    Batak: boolean;
    Batk: boolean;
    Bengali: boolean;
    Beng: boolean;
    Bhaiksuki: boolean;
    Bhks: boolean;
    Bopomofo: boolean;
    Bopo: boolean;
    Brahmi: boolean;
    Brah: boolean;
    Braille: boolean;
    Brai: boolean;
    Buginese: boolean;
    Bugi: boolean;
    Buhid: boolean;
    Buhd: boolean;
    Canadian_Aboriginal: boolean;
    Cans: boolean;
    Carian: boolean;
    Cari: boolean;
    Caucasian_Albanian: boolean;
    Aghb: boolean;
    Chakma: boolean;
    Cakm: boolean;
    Cham: boolean;
    Cherokee: boolean;
    Cher: boolean;
    Common: boolean;
    Zyyy: boolean;
    Coptic: boolean;
    Copt: boolean;
    Qaac: boolean;
    Cuneiform: boolean;
    Xsux: boolean;
    Cypriot: boolean;
    Cprt: boolean;
    Cyrillic: boolean;
    Cyrl: boolean;
    Deseret: boolean;
    Dsrt: boolean;
    Devanagari: boolean;
    Deva: boolean;
    Duployan: boolean;
    Dupl: boolean;
    Egyptian_Hieroglyphs: boolean;
    Egyp: boolean;
    Elbasan: boolean;
    Elba: boolean;
    Ethiopic: boolean;
    Ethi: boolean;
    Georgian: boolean;
    Geor: boolean;
    Glagolitic: boolean;
    Glag: boolean;
    Gothic: boolean;
    Goth: boolean;
    Grantha: boolean;
    Gran: boolean;
    Grek: boolean;
    Gujarati: boolean;
    Gujr: boolean;
    Gurmukhi: boolean;
    Guru: boolean;
    Hani: boolean;
    Hang: boolean;
    Hanunoo: boolean;
    Hano: boolean;
    Hatran: boolean;
    Hatr: boolean;
    Hebrew: boolean;
    Hebr: boolean;
    Hira: boolean;
    Imperial_Aramaic: boolean;
    Armi: boolean;
    Inherited: boolean;
    Zinh: boolean;
    Qaai: boolean;
    Inscriptional_Pahlavi: boolean;
    Phli: boolean;
    Inscriptional_Parthian: boolean;
    Prti: boolean;
    Javanese: boolean;
    Java: boolean;
    Kaithi: boolean;
    Kthi: boolean;
    Kannada: boolean;
    Knda: boolean;
    Kana: boolean;
    Kayah_Li: boolean;
    Kali: boolean;
    Kharoshthi: boolean;
    Khar: boolean;
    Khmer: boolean;
    Khmr: boolean;
    Khojki: boolean;
    Khoj: boolean;
    Khudawadi: boolean;
    Sind: boolean;
    Lao: boolean;
    Laoo: boolean;
    Latn: boolean;
    Lepcha: boolean;
    Lepc: boolean;
    Limbu: boolean;
    Limb: boolean;
    Linear_A: boolean;
    Lina: boolean;
    Linear_B: boolean;
    Linb: boolean;
    Lisu: boolean;
    Lycian: boolean;
    Lyci: boolean;
    Lydian: boolean;
    Lydi: boolean;
    Mahajani: boolean;
    Mahj: boolean;
    Malayalam: boolean;
    Mlym: boolean;
    Mandaic: boolean;
    Mand: boolean;
    Manichaean: boolean;
    Mani: boolean;
    Marchen: boolean;
    Marc: boolean;
    Masaram_Gondi: boolean;
    Gonm: boolean;
    Meetei_Mayek: boolean;
    Mtei: boolean;
    Mende_Kikakui: boolean;
    Mend: boolean;
    Meroitic_Cursive: boolean;
    Merc: boolean;
    Meroitic_Hieroglyphs: boolean;
    Mero: boolean;
    Miao: boolean;
    Plrd: boolean;
    Modi: boolean;
    Mongolian: boolean;
    Mong: boolean;
    Mro: boolean;
    Mroo: boolean;
    Multani: boolean;
    Mult: boolean;
    Myanmar: boolean;
    Mymr: boolean;
    Nabataean: boolean;
    Nbat: boolean;
    New_Tai_Lue: boolean;
    Talu: boolean;
    Newa: boolean;
    Nko: boolean;
    Nkoo: boolean;
    Nushu: boolean;
    Nshu: boolean;
    Ogham: boolean;
    Ogam: boolean;
    Ol_Chiki: boolean;
    Olck: boolean;
    Old_Hungarian: boolean;
    Hung: boolean;
    Old_Italic: boolean;
    Ital: boolean;
    Old_North_Arabian: boolean;
    Narb: boolean;
    Old_Permic: boolean;
    Perm: boolean;
    Old_Persian: boolean;
    Xpeo: boolean;
    Old_South_Arabian: boolean;
    Sarb: boolean;
    Old_Turkic: boolean;
    Orkh: boolean;
    Oriya: boolean;
    Orya: boolean;
    Osage: boolean;
    Osge: boolean;
    Osmanya: boolean;
    Osma: boolean;
    Pahawh_Hmong: boolean;
    Hmng: boolean;
    Palmyrene: boolean;
    Palm: boolean;
    Pau_Cin_Hau: boolean;
    Pauc: boolean;
    Phags_Pa: boolean;
    Phag: boolean;
    Phoenician: boolean;
    Phnx: boolean;
    Psalter_Pahlavi: boolean;
    Phlp: boolean;
    Rejang: boolean;
    Rjng: boolean;
    Runic: boolean;
    Runr: boolean;
    Samaritan: boolean;
    Samr: boolean;
    Saurashtra: boolean;
    Saur: boolean;
    Sharada: boolean;
    Shrd: boolean;
    Shavian: boolean;
    Shaw: boolean;
    Siddham: boolean;
    Sidd: boolean;
    SignWriting: boolean;
    Sgnw: boolean;
    Sinhala: boolean;
    Sinh: boolean;
    Sora_Sompeng: boolean;
    Sora: boolean;
    Soyombo: boolean;
    Soyo: boolean;
    Sundanese: boolean;
    Sund: boolean;
    Syloti_Nagri: boolean;
    Sylo: boolean;
    Syriac: boolean;
    Syrc: boolean;
    Tagalog: boolean;
    Tglg: boolean;
    Tagbanwa: boolean;
    Tagb: boolean;
    Tai_Le: boolean;
    Tale: boolean;
    Tai_Tham: boolean;
    Lana: boolean;
    Tai_Viet: boolean;
    Tavt: boolean;
    Takri: boolean;
    Takr: boolean;
    Tamil: boolean;
    Taml: boolean;
    Tangut: boolean;
    Tang: boolean;
    Telugu: boolean;
    Telu: boolean;
    Thaana: boolean;
    Thaa: boolean;
    Thai: boolean;
    Tibetan: boolean;
    Tibt: boolean;
    Tifinagh: boolean;
    Tfng: boolean;
    Tirhuta: boolean;
    Tirh: boolean;
    Ugaritic: boolean;
    Ugar: boolean;
    Vai: boolean;
    Vaii: boolean;
    Warang_Citi: boolean;
    Wara: boolean;
    Yi: boolean;
    Yiii: boolean;
    Zanabazar_Square: boolean;
    Zanb: boolean;
    Dogra: boolean;
    Gunjala_Gondi: boolean;
    Hanifi_Rohingya: boolean;
    Makasar: boolean;
    Medefaidrin: boolean;
    Old_Sogdian: boolean;
    Sogdian: boolean;
};
export declare function wrapToRegexName(name: string, negation?: boolean): string;
